@@ -51,16 +51,6 @@ class Utils(syspassclient.CheckType):
             if "message" in req["error"]:
                 if req["error"]["message"] == "Internal error":
                     raise ValueError('syspass client have return a Internal error, all operation is stopped')
-                # error_message += ", message: "
-                # error_message += str(req["error"]["message"])
-            # if "code" in req["error"]:
-            #     error_message += ", code: "
-            #     error_message += str(req["error"]["code"])
-            # if "data" in req["error"]:
-            #     error_message += ", data: "
-            #     error_message += str(req["error"]["data"])
-            # print(error_message)
-            # raise AnsibleError("SysPass Error -> %s" % error_message)
 
     def look_for_args(self, **parameters):
         """
@@ -96,7 +86,7 @@ class Utils(syspassclient.CheckType):
 
             # Test parameter type:
             # Str type
-            if syspassclient.Config().get_data()[parameters["method"]]["params_details"][parameter]["type"].lower() == "str":
+            if syspassclient.config.api_data[parameters["method"]]["params_details"][parameter]["type"].lower() == "str":
 
                 # If parameter is not require it can be None
                 if parameter in self.required_parameters(parameters["method"]):
@@ -109,7 +99,7 @@ class Utils(syspassclient.CheckType):
                         )
 
             # Int Type
-            elif syspassclient.Config().get_data()[parameters["method"]]["params_details"][parameter]["type"].lower() == "int":
+            elif syspassclient.config.api_data[parameters["method"]]["params_details"][parameter]["type"].lower() == "int":
 
                 # If parameter is not require it can be None
                 if parameter in self.required_parameters(parameters["method"]):
@@ -124,7 +114,7 @@ class Utils(syspassclient.CheckType):
                             "{0} must be a int instance or None, here that a {1}".format(parameter, str(type(value)))
                         )
             # List
-            elif syspassclient.Config().get_data()[parameters["method"]]["params_details"][parameter]["type"].lower() == "array":
+            elif syspassclient.config.api_data[parameters["method"]]["params_details"][parameter]["type"].lower() == "array":
                 # Never a array is in require parameter, and that for API v3.0 and v3.1
                 if list != type(value) and value is not None:
                     raise TypeError(
@@ -151,14 +141,15 @@ class Utils(syspassclient.CheckType):
         for parameter, value in parameters.items():
             if parameter == "method":
                 continue
-            if parameter not in syspassclient.Config().get_data()[parameters["method"]]["params_details"]:
-                raise (
-                    AttributeError(
-                        '"{0}" is not a valid parameter for syspass api {1}'.format(
-                            parameter, syspassclient.dd.syspass["api"]["version"]
+            if "params_details" in syspassclient.config.api_data[parameters["method"]]:
+                if parameter not in syspassclient.config.api_data[parameters["method"]]["params_details"]:
+                    raise (
+                        AttributeError(
+                            '"{0}" is not a valid parameter for syspass api {1}'.format(
+                                parameter, syspassclient.dd.syspass["api"]["version"]
+                            )
                         )
                     )
-                )
 
     @staticmethod
     def look_for_valid_method(**parameters):
@@ -166,7 +157,7 @@ class Utils(syspassclient.CheckType):
         Internal function it check if a method is valid in the actual API version
 
         :param parameters: a keys name, keys value dictionary
-        :type parameters: dict
+        :type parameters: **parameters
         """
 
         if "parameters" in parameters:
@@ -204,8 +195,8 @@ class Utils(syspassclient.CheckType):
         :rtype: list
         """
         requirement_list = []
-        for parameter in syspassclient.Config().get_data()[method]["params_details"]:
-            if syspassclient.Config().get_data()[method]["params_details"][parameter]["required"] is True:
+        for parameter in syspassclient.config.api_data[method]["params_details"]:
+            if syspassclient.config.api_data[method]["params_details"][parameter]["required"] is True:
                 requirement_list.append(parameter)
         return requirement_list
 
@@ -216,7 +207,7 @@ class Utils(syspassclient.CheckType):
         The parameter args must contain a key name 'method'
 
         :param parameters: parameters
-        :type parameters: dict
+        :type parameters: **parameters
         """
         if "parameters" in parameters:
             parameters = parameters["parameters"]
